;; Generated package description from casual.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "casual" "2.16.0.0.20260415.182614" "Transient user interfaces for various modes" '((emacs "30.1") (transient "0.9.0") (csv-mode "1.27")) :commit "6a3fbb40d3369614f36d9a37035942fa57572c5b" :authors '(("Charles Choi" . "kickingvegas@gmail.com")) :maintainer '("Charles Choi" . "kickingvegas@gmail.com") :keywords '("tools" "wp") :url "https://github.com/kickingvegas/casual")
